@@ -22,7 +22,7 @@ extern void 	output_xml_val_asc (char *value_name, char * value);
 extern void 	output_error(char *value);
 
 extern void 	flush_te1_pmon(void);
-extern void 	read_te1_56k_stat(int);
+extern void 	read_te1_56k_stat(unsigned char);
 extern void	banner(char *, int);
 extern int DoCommand(wan_udp_hdr_t*);
 
@@ -484,7 +484,6 @@ extern char*	get_hardware_level_interface_name(char* interface_name);
 extern int 	make_hardware_level_connection(void);
 extern void	cleanup_hardware_level_connection(void);
 
-extern void	read_te1_56k_stat(int);
 extern void	flush_te1_pmon(void);
 
 extern void	hw_line_trace(int trace_mode);
@@ -496,6 +495,7 @@ extern void	hw_flush_comm_err( void );
 extern void	hw_router_up_time(void);
 extern void	hw_read_code_version(void);
 extern void     hw_link_status(void);
+extern u_int32_t get_lb_modes(int silent);
 
 #ifndef LONG_MAX 
 #define LONG_MAX	((long)(~0UL>>1))
